@@ -37,6 +37,13 @@ class Run(object):
         arguments = self.arguments
         print(f"arguments passed: {arguments['command']}")
         # os.chdir('../')
+        if arguments['command'] == "clone":
+            retval = os.getcwd()
+            print(retval)
+            list_files = subprocess.run(["git clone https://dagshub.com/gagan3012/summarization.git"])
+            os.chdir('/summarization')
+            return list_files.returncode
+
         retval = os.getcwd()
         print(retval)
         list_files = subprocess.run(["make", arguments["command"]])
